summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/kscomet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/kscomet.cpp')
-rw-r--r--kstars/kstars/kscomet.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/kscomet.cpp b/kstars/kstars/kscomet.cpp
index 94ed1762..af14444b 100644
--- a/kstars/kstars/kscomet.cpp
+++ b/kstars/kstars/kscomet.cpp
@@ -48,8 +48,8 @@ KSComet::KSComet( KStarsData *_kd, TQString _s, TQString imfile,
//Compute the orbital Period from Kepler's 3rd law:
P = 365.2568984 * pow(a, 1.5); //period in days
- //If the name contains a "/", make this name2 and make name a truncated version without the leading "P/" or "C/"
- if ( name().contains( "/" ) ) {
+ //If the name tqcontains a "/", make this name2 and make name a truncated version without the leading "P/" or "C/"
+ if ( name().tqcontains( "/" ) ) {
setLongName( name() );
setName( name().mid( name().find("/") + 1 ) );
}